# No Nonsense

No nonsense is a static site generator. Essential idea is this:

Static Site Generation is a solved problem. All you need is a templating engine
and a config.

So, I am just using wheezy.template as a Template Engine and YAML as config.

### Features
1. Simple
2. You can do whatever you want

### Problems
1. You need to know HTML, CSS, JS to use effectively
2. Cannot connect to databases. So, things like comments, etc. are out of question

### Why YAML?

It is easier to read with "Naked Eye" as it does not have a lot of syntax. 
Disadvantage is whitespace is significant in YAML files and tabs vs spaces 
can cause confusion